<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sk_SK">
<context>
    <name>AppLauncher</name>
    <message>
        <location filename="../../src/tools/launcher/applaunchertool.cpp" line="40"/>
        <source>App Launcher</source>
        <translation>Spúšťač aplikácií</translation>
    </message>
    <message>
        <location filename="../../src/tools/launcher/applaunchertool.cpp" line="52"/>
        <source>Choose an app to open the capture</source>
        <translation>Vyberte aplikáciu na otvorenie snímky obrazovky</translation>
    </message>
</context>
<context>
    <name>AppLauncherWidget</name>
    <message>
        <location filename="../../src/tools/launcher/applauncherwidget.cpp" line="56"/>
        <source>Open With</source>
        <translation>Otvoriť s</translation>
    </message>
    <message>
        <location filename="../../src/tools/launcher/applauncherwidget.cpp" line="71"/>
        <source>Launch in terminal</source>
        <translation>Otvoriť v termináli</translation>
    </message>
    <message>
        <location filename="../../src/tools/launcher/applauncherwidget.cpp" line="72"/>
        <source>Keep open after selection</source>
        <translation>Nechať otvorené po výbere</translation>
    </message>
    <message>
        <location filename="../../src/tools/launcher/applauncherwidget.cpp" line="109"/>
        <location filename="../../src/tools/launcher/applauncherwidget.cpp" line="124"/>
        <source>Error</source>
        <translation>Chyba</translation>
    </message>
    <message>
        <location filename="../../src/tools/launcher/applauncherwidget.cpp" line="109"/>
        <source>Unable to write in</source>
        <translation>Zlyhal zápis do</translation>
    </message>
    <message>
        <location filename="../../src/tools/launcher/applauncherwidget.cpp" line="124"/>
        <source>Unable to launch in terminal.</source>
        <translation>Nepodarilo sa spustiť v termináli.</translation>
    </message>
</context>
<context>
    <name>ArrowTool</name>
    <message>
        <location filename="../../src/tools/arrow/arrowtool.cpp" line="92"/>
        <source>Arrow</source>
        <translation>Šípka</translation>
    </message>
    <message>
        <location filename="../../src/tools/arrow/arrowtool.cpp" line="104"/>
        <source>Set the Arrow as the paint tool</source>
        <translation>Nastaviť Šípku ako nástroj pre úpravy</translation>
    </message>
</context>
<context>
    <name>BlurTool</name>
    <message>
        <source>Blur</source>
        <translation type="vanished">Rozmazanie</translation>
    </message>
    <message>
        <source>Set Blur as the paint tool</source>
        <translation type="vanished">Nastaviť Rozmazanie ako nástroj pre úpravy</translation>
    </message>
</context>
<context>
    <name>CaptureLauncher</name>
    <message>
        <location filename="../../src/widgets/capturelauncher.cpp" line="67"/>
        <source>&lt;b&gt;Capture Mode&lt;/b&gt;</source>
        <translation>&lt;b&gt;Režim zachytávania&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../../src/widgets/capturelauncher.cpp" line="73"/>
        <source>Rectangular Region</source>
        <translation>Pravouhlá oblasť</translation>
    </message>
    <message>
        <location filename="../../src/widgets/capturelauncher.cpp" line="75"/>
        <source>Full Screen (All Monitors)</source>
        <translation>Celá obrazovka (všetky monitory)</translation>
    </message>
    <message>
        <location filename="../../src/widgets/capturelauncher.cpp" line="83"/>
        <source>No Delay</source>
        <translation>Bez oneskorenia</translation>
    </message>
    <message>
        <location filename="../../src/widgets/capturelauncher.cpp" line="90"/>
        <source> second</source>
        <translation> sekunda</translation>
    </message>
    <message>
        <location filename="../../src/widgets/capturelauncher.cpp" line="90"/>
        <source> seconds</source>
        <translation> sekundy</translation>
    </message>
    <message>
        <location filename="../../src/widgets/capturelauncher.cpp" line="94"/>
        <source>Take new screenshot</source>
        <translation>Zachytiť novú snímku</translation>
    </message>
    <message>
        <location filename="../../src/widgets/capturelauncher.cpp" line="103"/>
        <source>Area:</source>
        <translation>Oblasť:</translation>
    </message>
    <message>
        <location filename="../../src/widgets/capturelauncher.cpp" line="104"/>
        <source>Delay:</source>
        <translation>Oneskorenie:</translation>
    </message>
</context>
<context>
    <name>CaptureWidget</name>
    <message>
        <location filename="../../src/widgets/capture/capturewidget.cpp" line="99"/>
        <source>Unable to capture screen</source>
        <translation>Nepodarilo sa zachytiť obrazovku</translation>
    </message>
    <message>
        <location filename="../../src/widgets/capture/capturewidget.cpp" line="260"/>
        <source>Select an area with the mouse, or press Esc to exit.
Press Enter to capture the screen.
Press Right Click to show the color picker.
Use the Mouse Wheel to change the thickness of your tool.
Press Space to open the side panel.</source>
        <translation>Vyberte oblasť snímania pomocou myši alebo stlačte Esc pre ukončenie.
Stlačte Enter pre zachytenie obrazovky.
Kliknite pravým tlačidlom pre zobrazenie nástroja pre výber farby.
Použite kolečko myši pre zmenu hrúbky vybraného nástroja.
Stlačte medzerník pre otvorenie postranného panelu.</translation>
    </message>
    <message>
        <location filename="../../src/widgets/capture/capturewidget.cpp" line="617"/>
        <source>Tool Settings</source>
        <translation>Nastavenia nástrojov</translation>
    </message>
</context>
<context>
    <name>CircleCountTool</name>
    <message>
        <location filename="../../src/tools/circlecount/circlecounttool.cpp" line="39"/>
        <source>Circle Counter</source>
        <translation>Bodové počítadlo</translation>
    </message>
    <message>
        <location filename="../../src/tools/circlecount/circlecounttool.cpp" line="51"/>
        <source>Add an autoincrementing counter bubble</source>
        <translation>Pridá bublinu s číslom (vždy zvýšeným o jednotku)</translation>
    </message>
</context>
<context>
    <name>CircleTool</name>
    <message>
        <location filename="../../src/tools/circle/circletool.cpp" line="40"/>
        <source>Circle</source>
        <translation>Kruh</translation>
    </message>
    <message>
        <location filename="../../src/tools/circle/circletool.cpp" line="52"/>
        <source>Set the Circle as the paint tool</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>ConfigWindow</name>
    <message>
        <location filename="../../src/config/configwindow.cpp" line="43"/>
        <source>Configuration</source>
        <translation>Konfigurácia</translation>
    </message>
    <message>
        <location filename="../../src/config/configwindow.cpp" line="63"/>
        <source>Interface</source>
        <translation>Používateľské rozhranie</translation>
    </message>
    <message>
        <location filename="../../src/config/configwindow.cpp" line="69"/>
        <source>Filename Editor</source>
        <translation>Editor názvov súborov</translation>
    </message>
    <message>
        <location filename="../../src/config/configwindow.cpp" line="73"/>
        <source>General</source>
        <translation>Všeobecné</translation>
    </message>
</context>
<context>
    <name>Controller</name>
    <message>
        <location filename="../../src/core/controller.cpp" line="204"/>
        <source>&amp;Take Screenshot</source>
        <translation>&amp;Vytvoriť snímku</translation>
    </message>
    <message>
        <location filename="../../src/core/controller.cpp" line="209"/>
        <source>&amp;Open Launcher</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../src/core/controller.cpp" line="212"/>
        <source>&amp;Configuration</source>
        <translation>&amp;Konfigurácia</translation>
    </message>
    <message>
        <location filename="../../src/core/controller.cpp" line="215"/>
        <source>&amp;About</source>
        <translation>O &amp;programe</translation>
    </message>
    <message>
        <source>&amp;Information</source>
        <translation type="vanished">&amp;Informácie</translation>
    </message>
    <message>
        <location filename="../../src/core/controller.cpp" line="217"/>
        <source>&amp;Quit</source>
        <translation>&amp;Ukončiť</translation>
    </message>
</context>
<context>
    <name>CopyTool</name>
    <message>
        <location filename="../../src/tools/copy/copytool.cpp" line="41"/>
        <source>Copy</source>
        <translation>Kopírovať</translation>
    </message>
    <message>
        <location filename="../../src/tools/copy/copytool.cpp" line="53"/>
        <source>Copy the selection into the clipboard</source>
        <translation>Kopírovať výber do schránky</translation>
    </message>
</context>
<context>
    <name>DBusUtils</name>
    <message>
        <location filename="../../src/utils/dbusutils.cpp" line="52"/>
        <source>Unable to connect via DBus</source>
        <translation>Nie je možné pripojiť sa prostredníctvom DBus</translation>
    </message>
</context>
<context>
    <name>ExitTool</name>
    <message>
        <location filename="../../src/tools/exit/exittool.cpp" line="40"/>
        <source>Exit</source>
        <translation>Ukončiť</translation>
    </message>
    <message>
        <location filename="../../src/tools/exit/exittool.cpp" line="52"/>
        <source>Leave the capture screen</source>
        <translation>Opustiť obrazovku so zachytávaním obrazovky</translation>
    </message>
</context>
<context>
    <name>FileNameEditor</name>
    <message>
        <location filename="../../src/config/filenameeditor.cpp" line="39"/>
        <source>Edit the name of your captures:</source>
        <translation>Upraviť meno vašich snímok obrazovky:</translation>
    </message>
    <message>
        <location filename="../../src/config/filenameeditor.cpp" line="43"/>
        <source>Edit:</source>
        <translation>Upraviť:</translation>
    </message>
    <message>
        <location filename="../../src/config/filenameeditor.cpp" line="45"/>
        <source>Preview:</source>
        <translation>Ukážka:</translation>
    </message>
    <message>
        <location filename="../../src/config/filenameeditor.cpp" line="88"/>
        <source>Save</source>
        <translation>Uložiť</translation>
    </message>
    <message>
        <location filename="../../src/config/filenameeditor.cpp" line="91"/>
        <source>Saves the pattern</source>
        <translation>Uloží vzor</translation>
    </message>
    <message>
        <location filename="../../src/config/filenameeditor.cpp" line="93"/>
        <source>Reset</source>
        <translation>Resetovať</translation>
    </message>
    <message>
        <location filename="../../src/config/filenameeditor.cpp" line="96"/>
        <source>Restores the saved pattern</source>
        <translation>Vráti zmeny</translation>
    </message>
    <message>
        <location filename="../../src/config/filenameeditor.cpp" line="98"/>
        <source>Clear</source>
        <translation>Vyčistiť</translation>
    </message>
    <message>
        <location filename="../../src/config/filenameeditor.cpp" line="102"/>
        <source>Deletes the name</source>
        <translation>Vymaže meno</translation>
    </message>
</context>
<context>
    <name>GeneneralConf</name>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="121"/>
        <location filename="../../src/config/geneneralconf.cpp" line="258"/>
        <source>Import</source>
        <translation>Importovať</translation>
    </message>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="128"/>
        <location filename="../../src/config/geneneralconf.cpp" line="136"/>
        <location filename="../../src/config/geneneralconf.cpp" line="160"/>
        <location filename="../../src/config/geneneralconf.cpp" line="370"/>
        <source>Error</source>
        <translation>Chyba</translation>
    </message>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="128"/>
        <source>Unable to read file.</source>
        <translation>Zlyhalo čítanie súboru.</translation>
    </message>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="136"/>
        <location filename="../../src/config/geneneralconf.cpp" line="160"/>
        <source>Unable to write file.</source>
        <translation>Zlyhal zápis do súboru.</translation>
    </message>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="147"/>
        <source>Save File</source>
        <translation>Uložiť súbor</translation>
    </message>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="170"/>
        <source>Confirm Reset</source>
        <translation>Potvrdiť Reset</translation>
    </message>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="171"/>
        <source>Are you sure you want to reset the configuration?</source>
        <translation>Naozaj si želáte resetovať aktuálnu konfiguráciu?</translation>
    </message>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="181"/>
        <source>Show help message</source>
        <translation>Zobraziť nápovedu</translation>
    </message>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="185"/>
        <source>Show the help message at the beginning in the capture mode.</source>
        <translation>Zobraziť nápovedu na začiatku počas režimu zachytávania obrazovky.</translation>
    </message>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="196"/>
        <source>Show the side panel button</source>
        <translation>Zobraziť tlačidlo na postrannom paneli</translation>
    </message>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="199"/>
        <source>Show the side panel toggle button in the capture mode.</source>
        <translation>V režime zachytávania zobrazovať tlačidlo na postrannom paneli.</translation>
    </message>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="210"/>
        <location filename="../../src/config/geneneralconf.cpp" line="214"/>
        <source>Show desktop notifications</source>
        <translation>Zobraziť systémové upozornenia</translation>
    </message>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="227"/>
        <source>Show tray icon</source>
        <translation>Zobraziť stavovú ikonu</translation>
    </message>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="231"/>
        <source>Show the systemtray icon</source>
        <translation>Zobraziť ikonu v stavovej oblasti</translation>
    </message>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="246"/>
        <source>Configuration File</source>
        <translation>Súbor s konfiguráciou</translation>
    </message>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="251"/>
        <source>Export</source>
        <translation>Exportovať</translation>
    </message>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="265"/>
        <source>Reset</source>
        <translation>Resetovať</translation>
    </message>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="276"/>
        <source>Launch at startup</source>
        <translation>Spúšťať pri štarte</translation>
    </message>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="280"/>
        <source>Launch Flameshot</source>
        <translation>Spustiť Flameshot</translation>
    </message>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="290"/>
        <source>Close after capture</source>
        <translation>Zavrieť po vytvorení snímky</translation>
    </message>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="294"/>
        <source>Close after taking a screenshot</source>
        <translation>Zatvoriť po vytvorení snímky obrazovky</translation>
    </message>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="306"/>
        <source>Copy URL after upload</source>
        <translation>Kopírovať URL po uploade</translation>
    </message>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="311"/>
        <source>Copy URL and close window after upload</source>
        <translation>Po nahratí skopírovať URL a zavrieť okno</translation>
    </message>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="322"/>
        <source>Save image after copy</source>
        <translation>Uložiť obrázok po kopírovaní</translation>
    </message>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="323"/>
        <source>Save image file after copying it</source>
        <translation>Uložiť obrázok so súborom po jeho skopírovaní</translation>
    </message>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="332"/>
        <source>Save Path</source>
        <translation>Cesta pre ukladanie</translation>
    </message>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="344"/>
        <source>Change...</source>
        <translation>Zmeniť...</translation>
    </message>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="363"/>
        <source>Choose a Folder</source>
        <translation>Vyberte priečinok</translation>
    </message>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="370"/>
        <source>Unable to write to directory.</source>
        <translation>Zápis do adresára nie je možný.</translation>
    </message>
</context>
<context>
    <name>ImgurUploader</name>
    <message>
        <location filename="../../src/tools/imgur/imguruploader.cpp" line="48"/>
        <source>Upload to Imgur</source>
        <translation>Nahrať na Imgur</translation>
    </message>
    <message>
        <location filename="../../src/tools/imgur/imguruploader.cpp" line="55"/>
        <source>Uploading Image</source>
        <translation>Nahrávam obrázok</translation>
    </message>
    <message>
        <location filename="../../src/tools/imgur/imguruploader.cpp" line="156"/>
        <source>Copy URL</source>
        <translation>Kopírovať URL</translation>
    </message>
    <message>
        <location filename="../../src/tools/imgur/imguruploader.cpp" line="157"/>
        <source>Open URL</source>
        <translation>Otvoriť URL</translation>
    </message>
    <message>
        <location filename="../../src/tools/imgur/imguruploader.cpp" line="158"/>
        <source>Delete image</source>
        <translation>Vymazať obrázok</translation>
    </message>
    <message>
        <location filename="../../src/tools/imgur/imguruploader.cpp" line="159"/>
        <source>Image to Clipboard.</source>
        <translation>Obrázok do schránky.</translation>
    </message>
    <message>
        <location filename="../../src/tools/imgur/imguruploader.cpp" line="184"/>
        <location filename="../../src/tools/imgur/imguruploader.cpp" line="200"/>
        <source>Unable to open the URL.</source>
        <translation>Nepodarilo sa otvoriť URL.</translation>
    </message>
    <message>
        <location filename="../../src/tools/imgur/imguruploader.cpp" line="192"/>
        <source>URL copied to clipboard.</source>
        <translation>URL skopírovaná do schránky.</translation>
    </message>
    <message>
        <location filename="../../src/tools/imgur/imguruploader.cpp" line="208"/>
        <source>Screenshot copied to clipboard.</source>
        <translation>Snímka obrazovky bola skopírovaná do schránky.</translation>
    </message>
</context>
<context>
    <name>ImgurUploaderTool</name>
    <message>
        <location filename="../../src/tools/imgur/imguruploadertool.cpp" line="41"/>
        <source>Image Uploader</source>
        <translation>Uploader obrázkov</translation>
    </message>
    <message>
        <location filename="../../src/tools/imgur/imguruploadertool.cpp" line="53"/>
        <source>Upload the selection to Imgur</source>
        <translation>Nahrať výber na Imgur</translation>
    </message>
</context>
<context>
    <name>InfoWindow</name>
    <message>
        <location filename="../../src/widgets/infowindow.cpp" line="40"/>
        <source>About</source>
        <translation>O programe</translation>
    </message>
    <message>
        <location filename="../../src/widgets/infowindow.cpp" line="62"/>
        <source>SPACEBAR</source>
        <translation>MEDZERNÍK</translation>
    </message>
    <message>
        <location filename="../../src/widgets/infowindow.cpp" line="63"/>
        <source>Right Click</source>
        <translation>Kliknutie pravým tlačidlom</translation>
    </message>
    <message>
        <location filename="../../src/widgets/infowindow.cpp" line="64"/>
        <source>Mouse Wheel</source>
        <translation>Kolečko myši</translation>
    </message>
    <message>
        <location filename="../../src/widgets/infowindow.cpp" line="67"/>
        <source>Move selection 1px</source>
        <translation>Presunúť výber o 1 px</translation>
    </message>
    <message>
        <location filename="../../src/widgets/infowindow.cpp" line="68"/>
        <source>Resize selection 1px</source>
        <translation>Zmeniť rozmery výberu o 1 px</translation>
    </message>
    <message>
        <location filename="../../src/widgets/infowindow.cpp" line="69"/>
        <source>Quit capture</source>
        <translation>Ukončiť zachytávanie obrazovky</translation>
    </message>
    <message>
        <location filename="../../src/widgets/infowindow.cpp" line="70"/>
        <source>Copy to clipboard</source>
        <translation>Kopírovať do schránky</translation>
    </message>
    <message>
        <location filename="../../src/widgets/infowindow.cpp" line="71"/>
        <source>Save selection as a file</source>
        <translation>Zapísať výber do súboru</translation>
    </message>
    <message>
        <location filename="../../src/widgets/infowindow.cpp" line="72"/>
        <source>Undo the last modification</source>
        <translation>Vrátiť poslednú úpravu</translation>
    </message>
    <message>
        <location filename="../../src/widgets/infowindow.cpp" line="73"/>
        <source>Toggle visibility of sidebar with options of the selected tool</source>
        <translation>Prepnúť viditeľnosť bočnej lišty s možnosťami vybraného nástroja</translation>
    </message>
    <message>
        <location filename="../../src/widgets/infowindow.cpp" line="74"/>
        <source>Show color picker</source>
        <translation>Zobraziť dialóg na výber farby</translation>
    </message>
    <message>
        <location filename="../../src/widgets/infowindow.cpp" line="75"/>
        <source>Change the tool&apos;s thickness</source>
        <translation>Zmena hrúbky nástroja</translation>
    </message>
    <message>
        <location filename="../../src/widgets/infowindow.cpp" line="82"/>
        <source>Available shortcuts in the screen capture mode.</source>
        <translation>Dostupné klávesové skratky v režime zachytávania obrazovky.</translation>
    </message>
    <message>
        <location filename="../../src/widgets/infowindow.cpp" line="93"/>
        <source>Key</source>
        <translation>Kláves</translation>
    </message>
    <message>
        <location filename="../../src/widgets/infowindow.cpp" line="93"/>
        <source>Description</source>
        <translation>Popis</translation>
    </message>
    <message>
        <location filename="../../src/widgets/infowindow.cpp" line="126"/>
        <source>&lt;u&gt;&lt;b&gt;License&lt;/b&gt;&lt;/u&gt;</source>
        <translation>&lt;u&gt;&lt;b&gt;Licencia&lt;/b&gt;&lt;/u&gt;</translation>
    </message>
    <message>
        <location filename="../../src/widgets/infowindow.cpp" line="134"/>
        <source>&lt;u&gt;&lt;b&gt;Version&lt;/b&gt;&lt;/u&gt;</source>
        <translation>&lt;u&gt;&lt;b&gt;Verzia&lt;/b&gt;&lt;/u&gt;</translation>
    </message>
    <message>
        <location filename="../../src/widgets/infowindow.cpp" line="145"/>
        <source>&lt;u&gt;&lt;b&gt;Shortcuts&lt;/b&gt;&lt;/u&gt;</source>
        <translation>&lt;u&gt;&lt;b&gt;Klávesové skratky&lt;/b&gt;&lt;/u&gt;</translation>
    </message>
</context>
<context>
    <name>LineTool</name>
    <message>
        <location filename="../../src/tools/line/linetool.cpp" line="43"/>
        <source>Line</source>
        <translation>Čiara</translation>
    </message>
    <message>
        <location filename="../../src/tools/line/linetool.cpp" line="55"/>
        <source>Set the Line as the paint tool</source>
        <translation>Nastaviť Čiaru ako nástroj pre úpravy</translation>
    </message>
</context>
<context>
    <name>MarkerTool</name>
    <message>
        <location filename="../../src/tools/marker/markertool.cpp" line="43"/>
        <source>Marker</source>
        <translation>Fixka</translation>
    </message>
    <message>
        <location filename="../../src/tools/marker/markertool.cpp" line="55"/>
        <source>Set the Marker as the paint tool</source>
        <translation>Nastaviť Fixku ako nástroj pre úpravy</translation>
    </message>
</context>
<context>
    <name>MoveTool</name>
    <message>
        <location filename="../../src/tools/move/movetool.cpp" line="40"/>
        <source>Move</source>
        <translation>Presun</translation>
    </message>
    <message>
        <location filename="../../src/tools/move/movetool.cpp" line="52"/>
        <source>Move the selection area</source>
        <translation>Presunúť oblasť výberu</translation>
    </message>
</context>
<context>
    <name>PencilTool</name>
    <message>
        <location filename="../../src/tools/pencil/penciltool.cpp" line="34"/>
        <source>Pencil</source>
        <translation>Ceruzka</translation>
    </message>
    <message>
        <location filename="../../src/tools/pencil/penciltool.cpp" line="46"/>
        <source>Set the Pencil as the paint tool</source>
        <translation>Nastaviť Ceruzku ako nástroj pre úpravy</translation>
    </message>
</context>
<context>
    <name>PinTool</name>
    <message>
        <location filename="../../src/tools/pin/pintool.cpp" line="40"/>
        <source>Pin Tool</source>
        <translation>Pripínačik</translation>
    </message>
    <message>
        <location filename="../../src/tools/pin/pintool.cpp" line="52"/>
        <source>Pin image on the desktop</source>
        <translation>Pripnúť obrázok na plochu</translation>
    </message>
</context>
<context>
    <name>PixelateTool</name>
    <message>
        <location filename="../../src/tools/pixelate/pixelatetool.cpp" line="40"/>
        <source>Pixelate</source>
        <translation>Rozštvorčekovanie</translation>
    </message>
    <message>
        <location filename="../../src/tools/pixelate/pixelatetool.cpp" line="52"/>
        <source>Set Pixelate as the paint tool</source>
        <translation>Nastaviť Rozštvorčekovanie ako nástroj pre úpravy</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../src/main.cpp" line="82"/>
        <location filename="../../src/main.cpp" line="244"/>
        <location filename="../../src/main.cpp" line="399"/>
        <location filename="../../src/main.cpp" line="426"/>
        <location filename="../../src/main.cpp" line="458"/>
        <source>Unable to connect via DBus</source>
        <translation>Nie je možné pripojiť sa prostredníctvom DBus</translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="104"/>
        <source>Powerful yet simple to use screenshot software.</source>
        <translation>Mocný, no zároveň tiež jednoduchý softvér na zachytávanie obrazovky.</translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="105"/>
        <source>See</source>
        <translation>Pozrite</translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="108"/>
        <source>Capture the entire desktop.</source>
        <translation>Zachytiť celú plochu.</translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="110"/>
        <source>Open the capture launcher.</source>
        <translation>Otvoriť spúšťač zachytávania.</translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="112"/>
        <source>Start a manual capture in GUI mode.</source>
        <translation>Spustiť manuálne zachytávanie v GUI režime.</translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="114"/>
        <source>Configure</source>
        <translation>Konfigurovať</translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="116"/>
        <source>Capture a single screen.</source>
        <translation>Zachytiť jeden monitor.</translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="120"/>
        <source>Path where the capture will be saved</source>
        <translation>Cesta, kam bude snímka uložená</translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="123"/>
        <source>Save the capture to the clipboard</source>
        <translation>Uložiť snímku do schránky</translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="125"/>
        <source>Delay time in milliseconds</source>
        <translation>Oneskorenie času v milisekundách</translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="128"/>
        <source>Set the filename pattern</source>
        <translation>Nastaviť masku pre pomenovanie súborov</translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="131"/>
        <source>Enable or disable the trayicon</source>
        <translation>Povoliť alebo zakázať ikonu v lište</translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="134"/>
        <source>Enable or disable run at startup</source>
        <translation>Povoliť alebo zakázáť spustenie pri štarte systému</translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="138"/>
        <source>Show the help message in the capture mode</source>
        <translation>Ukazovať nápovedu v režime zachytávania</translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="141"/>
        <source>Define the main UI color</source>
        <translation>Nastaviť farbu hlavného používateľského rozhrania</translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="144"/>
        <source>Define the contrast UI color</source>
        <translation>Nastaviť kontrastnú farbu používateľského rozhrania</translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="147"/>
        <source>Print raw PNG capture</source>
        <translation>Zobraziť surovú PNG snímku</translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="150"/>
        <source>Define the screen to capture</source>
        <translation>Nastaviť monitor, ktorý bude zachytávaný</translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="151"/>
        <source>default: screen containing the cursor</source>
        <translation>predvolené: monitor, na ktorom je kurzor myši</translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="152"/>
        <source>Screen number</source>
        <translation>Číslo monitora</translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="161"/>
        <source>Invalid color, this flag supports the following formats:
- #RGB (each of R, G, and B is a single hex digit)
- #RRGGBB
- #RRRGGGBBB
- #RRRRGGGGBBBB
- Named colors like &apos;blue&apos; or &apos;red&apos;
You may need to escape the &apos;#&apos; sign as in &apos;\#FFF&apos;</source>
        <translation>Neplatná farba, tento prepínač podporuje nasledovné formáty:
- #RGB (každá zo zložiek R, G a B je samostatným hexadecimálnym číslom)
- #RRGGBB
- #RRRGGGBBB
- #RRRRGGGGBBBB
- anglické mená farieb ako &apos;blue&apos; alebo &apos;red&apos;
Možno budete musieť napísať pred &apos;#&apos; opačnú lomku, teda &apos;\#FFF&apos;</translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="170"/>
        <source>Invalid delay, it must be higher than 0</source>
        <translation>Neplatné oneskorenie, musí byť vyššie ako 0</translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="172"/>
        <source>Invalid screen number, it must be non negative</source>
        <translation>Neplatné číslo monitora, môže byť len kladné</translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="179"/>
        <source>Invalid path, it must be a real path in the system</source>
        <translation>Neplatná cesta, musí sa jednať o skutočnú cestu na systéme</translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="189"/>
        <source>Invalid value, it must be defined as &apos;true&apos; or &apos;false&apos;</source>
        <translation>Neplatná hodnota, musí byť definovaná ako &apos;pravda&apos; alebo &apos;nepravda&apos;</translation>
    </message>
    <message>
        <location filename="../../src/tools/launcher/openwithprogram.cpp" line="45"/>
        <source>Error</source>
        <translation>Chyba</translation>
    </message>
    <message>
        <location filename="../../src/tools/launcher/openwithprogram.cpp" line="46"/>
        <source>Unable to write in</source>
        <translation>Zlyhal zápis do</translation>
    </message>
    <message>
        <location filename="../../src/utils/screenshotsaver.cpp" line="42"/>
        <source>Capture saved to clipboard.</source>
        <translation>Snímka uložená do schránky.</translation>
    </message>
    <message>
        <location filename="../../src/utils/screenshotsaver.cpp" line="47"/>
        <source>Capture saved to clipboard</source>
        <translation>Snímka uložená do schránky</translation>
    </message>
    <message>
        <location filename="../../src/utils/screenshotsaver.cpp" line="66"/>
        <location filename="../../src/utils/screenshotsaver.cpp" line="107"/>
        <source>Capture saved as </source>
        <translation>Snímka uložená ako </translation>
    </message>
    <message>
        <location filename="../../src/utils/screenshotsaver.cpp" line="69"/>
        <location filename="../../src/utils/screenshotsaver.cpp" line="110"/>
        <source>Error trying to save as </source>
        <translation>Chyba pri ukladaní do </translation>
    </message>
    <message>
        <location filename="../../src/utils/screenshotsaver.cpp" line="112"/>
        <source>Save Error</source>
        <translation>Chyba pri ukladaní</translation>
    </message>
    <message>
        <location filename="../../src/tools/imgur/imguruploader.cpp" line="88"/>
        <source>URL copied to clipboard.</source>
        <translation>URL skopírovaná do schránky.</translation>
    </message>
    <message>
        <location filename="../../src/cli/commandlineparser.cpp" line="64"/>
        <source>Options</source>
        <translation>Voľby</translation>
    </message>
    <message>
        <location filename="../../src/cli/commandlineparser.cpp" line="77"/>
        <source>Arguments</source>
        <translation>Argumenty</translation>
    </message>
    <message>
        <location filename="../../src/cli/commandlineparser.cpp" line="350"/>
        <source>arguments</source>
        <translation>argumenty</translation>
    </message>
    <message>
        <location filename="../../src/cli/commandlineparser.cpp" line="351"/>
        <source>Usage</source>
        <translation>Použitie</translation>
    </message>
    <message>
        <location filename="../../src/cli/commandlineparser.cpp" line="351"/>
        <source>options</source>
        <translation>voľby</translation>
    </message>
    <message>
        <location filename="../../src/cli/commandlineparser.cpp" line="358"/>
        <source>Per default runs Flameshot in the background and   adds a tray icon for configuration.</source>
        <translation>Štandardne sa Flameshot spúšťa na pozadí a pridáva do lišty ikonu, ktorou je ho možné ovládať.</translation>
    </message>
</context>
<context>
    <name>RectangleTool</name>
    <message>
        <location filename="../../src/tools/rectangle/rectangletool.cpp" line="40"/>
        <source>Rectangle</source>
        <translation>Obdĺžnik</translation>
    </message>
    <message>
        <location filename="../../src/tools/rectangle/rectangletool.cpp" line="52"/>
        <source>Set the Rectangle as the paint tool</source>
        <translation>Nastaviť Obdĺžnik ako nástroj pre úpravy</translation>
    </message>
</context>
<context>
    <name>RedoTool</name>
    <message>
        <location filename="../../src/tools/redo/redotool.cpp" line="40"/>
        <source>Redo</source>
        <translation>Znova</translation>
    </message>
    <message>
        <location filename="../../src/tools/redo/redotool.cpp" line="52"/>
        <source>Redo the next modification</source>
        <translation>Zopakovať úpravu</translation>
    </message>
</context>
<context>
    <name>SaveTool</name>
    <message>
        <location filename="../../src/tools/save/savetool.cpp" line="41"/>
        <source>Save</source>
        <translation>Uložiť</translation>
    </message>
    <message>
        <location filename="../../src/tools/save/savetool.cpp" line="53"/>
        <source>Save the capture</source>
        <translation>Uložiť snímku obrazovky</translation>
    </message>
</context>
<context>
    <name>ScreenGrabber</name>
    <message>
        <location filename="../../src/utils/screengrabber.cpp" line="84"/>
        <source>Unable to capture screen</source>
        <translation>Nepodarilo sa zachytiť obrazovku</translation>
    </message>
</context>
<context>
    <name>SelectionTool</name>
    <message>
        <location filename="../../src/tools/selection/selectiontool.cpp" line="46"/>
        <source>Rectangular Selection</source>
        <translation>Obdĺžnikový výber</translation>
    </message>
    <message>
        <location filename="../../src/tools/selection/selectiontool.cpp" line="58"/>
        <source>Set Selection as the paint tool</source>
        <translation>Nastaviť Výber ako nástroj pre úpravy</translation>
    </message>
</context>
<context>
    <name>SidePanelWidget</name>
    <message>
        <location filename="../../src/widgets/panel/sidepanelwidget.cpp" line="71"/>
        <source>Active thickness:</source>
        <translation>Aktívna hrúbka:</translation>
    </message>
    <message>
        <location filename="../../src/widgets/panel/sidepanelwidget.cpp" line="72"/>
        <source>Active color:</source>
        <translation>Aktívna farba:</translation>
    </message>
    <message>
        <location filename="../../src/widgets/panel/sidepanelwidget.cpp" line="217"/>
        <source>Press ESC to cancel</source>
        <translation>Stlačte ESC pre zrušenie</translation>
    </message>
    <message>
        <location filename="../../src/widgets/panel/sidepanelwidget.cpp" line="219"/>
        <source>Grab Color</source>
        <translation>Snímať farbu</translation>
    </message>
</context>
<context>
    <name>SizeIndicatorTool</name>
    <message>
        <location filename="../../src/tools/sizeindicator/sizeindicatortool.cpp" line="40"/>
        <source>Selection Size Indicator</source>
        <translation>Ukazovateľ veľkosti výberu</translation>
    </message>
    <message>
        <location filename="../../src/tools/sizeindicator/sizeindicatortool.cpp" line="52"/>
        <source>Show the dimensions of the selection (X Y)</source>
        <translation>Zobraziť rozmery výberu (X Y)</translation>
    </message>
</context>
<context>
    <name>StrftimeChooserWidget</name>
    <message>
        <location filename="../../src/config/strftimechooserwidget.cpp" line="50"/>
        <source>Century (00-99)</source>
        <translation>Storočie (00-99)</translation>
    </message>
    <message>
        <location filename="../../src/config/strftimechooserwidget.cpp" line="51"/>
        <source>Year (00-99)</source>
        <translation>Rok (00-99)</translation>
    </message>
    <message>
        <location filename="../../src/config/strftimechooserwidget.cpp" line="52"/>
        <source>Year (2000)</source>
        <translation>Rok (2000)</translation>
    </message>
    <message>
        <location filename="../../src/config/strftimechooserwidget.cpp" line="53"/>
        <source>Month Name (jan)</source>
        <translation>Meno mesiaca (jan)</translation>
    </message>
    <message>
        <location filename="../../src/config/strftimechooserwidget.cpp" line="54"/>
        <source>Month Name (january)</source>
        <translation>Meno mesiaca (január)</translation>
    </message>
    <message>
        <location filename="../../src/config/strftimechooserwidget.cpp" line="55"/>
        <source>Month (01-12)</source>
        <translation>Mesiac (01-12)</translation>
    </message>
    <message>
        <location filename="../../src/config/strftimechooserwidget.cpp" line="56"/>
        <source>Week Day (1-7)</source>
        <translation>Deň v týždni (1-7)</translation>
    </message>
    <message>
        <location filename="../../src/config/strftimechooserwidget.cpp" line="57"/>
        <source>Week (01-53)</source>
        <translation>Týždeň (01-53)</translation>
    </message>
    <message>
        <location filename="../../src/config/strftimechooserwidget.cpp" line="58"/>
        <source>Day Name (mon)</source>
        <translation>Meno dňa (pon)</translation>
    </message>
    <message>
        <location filename="../../src/config/strftimechooserwidget.cpp" line="59"/>
        <source>Day Name (monday)</source>
        <translation>Meno dňa (pondelok)</translation>
    </message>
    <message>
        <location filename="../../src/config/strftimechooserwidget.cpp" line="60"/>
        <source>Day (01-31)</source>
        <translation>Deň (01-31)</translation>
    </message>
    <message>
        <location filename="../../src/config/strftimechooserwidget.cpp" line="61"/>
        <source>Day of Month (1-31)</source>
        <translation>Deň v mesiaci (1-31)</translation>
    </message>
    <message>
        <location filename="../../src/config/strftimechooserwidget.cpp" line="62"/>
        <source>Day (001-366)</source>
        <translation>Deň (001-366)</translation>
    </message>
    <message>
        <location filename="../../src/config/strftimechooserwidget.cpp" line="63"/>
        <source>Time (%H-%M-%S)</source>
        <translation>Čas (%H-%M-%S)</translation>
    </message>
    <message>
        <location filename="../../src/config/strftimechooserwidget.cpp" line="64"/>
        <source>Time (%H-%M)</source>
        <translation>Čas (%H-%M)</translation>
    </message>
    <message>
        <location filename="../../src/config/strftimechooserwidget.cpp" line="65"/>
        <source>Hour (00-23)</source>
        <translation>Hodina (00-23)</translation>
    </message>
    <message>
        <location filename="../../src/config/strftimechooserwidget.cpp" line="66"/>
        <source>Hour (01-12)</source>
        <translation>Hodina (01-12)</translation>
    </message>
    <message>
        <location filename="../../src/config/strftimechooserwidget.cpp" line="67"/>
        <source>Minute (00-59)</source>
        <translation>Minúta (00-59)</translation>
    </message>
    <message>
        <location filename="../../src/config/strftimechooserwidget.cpp" line="68"/>
        <source>Second (00-59)</source>
        <translation>Sekunda (00-59)</translation>
    </message>
    <message>
        <location filename="../../src/config/strftimechooserwidget.cpp" line="69"/>
        <source>Full Date (%m/%d/%y)</source>
        <translation>Celý dátum (%m/%d/%y)</translation>
    </message>
    <message>
        <location filename="../../src/config/strftimechooserwidget.cpp" line="70"/>
        <source>Full Date (%Y-%m-%d)</source>
        <translation>Celý dátum (%Y-%m-%d)</translation>
    </message>
</context>
<context>
    <name>SystemNotification</name>
    <message>
        <location filename="../../src/utils/systemnotification.cpp" line="36"/>
        <source>Flameshot Info</source>
        <translation>Informácie o programe Flameshot</translation>
    </message>
</context>
<context>
    <name>TextConfig</name>
    <message>
        <location filename="../../src/tools/text/textconfig.cpp" line="54"/>
        <source>StrikeOut</source>
        <translation>Preškrtnuté</translation>
    </message>
    <message>
        <location filename="../../src/tools/text/textconfig.cpp" line="63"/>
        <source>Underline</source>
        <translation>Podčiarknuté</translation>
    </message>
    <message>
        <location filename="../../src/tools/text/textconfig.cpp" line="72"/>
        <source>Bold</source>
        <translation>Tučné</translation>
    </message>
    <message>
        <location filename="../../src/tools/text/textconfig.cpp" line="81"/>
        <source>Italic</source>
        <translation>Kurzíva</translation>
    </message>
</context>
<context>
    <name>TextTool</name>
    <message>
        <location filename="../../src/tools/text/texttool.cpp" line="63"/>
        <source>Text</source>
        <translation>Text</translation>
    </message>
    <message>
        <location filename="../../src/tools/text/texttool.cpp" line="75"/>
        <source>Add text to your capture</source>
        <translation>Pridať text do snímky</translation>
    </message>
</context>
<context>
    <name>UIcolorEditor</name>
    <message>
        <location filename="../../src/config/uicoloreditor.cpp" line="32"/>
        <source>UI Color Editor</source>
        <translation>Editor farieb používateľského rozhrania</translation>
    </message>
    <message>
        <location filename="../../src/config/uicoloreditor.cpp" line="107"/>
        <source>Change the color moving the selectors and see the changes in the preview buttons.</source>
        <translation>Presunom bežcov nastavte farbu a sledujte tieto zmeny v náhľade.</translation>
    </message>
    <message>
        <location filename="../../src/config/uicoloreditor.cpp" line="119"/>
        <source>Select a Button to modify it</source>
        <translation>Kliknite na tlačidlo pre jeho úpravu</translation>
    </message>
    <message>
        <location filename="../../src/config/uicoloreditor.cpp" line="129"/>
        <source>Main Color</source>
        <translation>Hlavná farba</translation>
    </message>
    <message>
        <location filename="../../src/config/uicoloreditor.cpp" line="133"/>
        <source>Click on this button to set the edition mode of the main color.</source>
        <translation>Pre nastavenie hlavnej farby kliknite na toto tlačidlo.</translation>
    </message>
    <message>
        <location filename="../../src/config/uicoloreditor.cpp" line="144"/>
        <source>Contrast Color</source>
        <translation>Kontrastná farba</translation>
    </message>
    <message>
        <location filename="../../src/config/uicoloreditor.cpp" line="149"/>
        <source>Click on this button to set the edition mode of the contrast color.</source>
        <translation>Pre nastavenie kontrastnej farby kliknite na toto tlačidlo.</translation>
    </message>
</context>
<context>
    <name>UndoTool</name>
    <message>
        <location filename="../../src/tools/undo/undotool.cpp" line="40"/>
        <source>Undo</source>
        <translation>Späť</translation>
    </message>
    <message>
        <location filename="../../src/tools/undo/undotool.cpp" line="52"/>
        <source>Undo the last modification</source>
        <translation>Vrátiť poslednú úpravu</translation>
    </message>
</context>
<context>
    <name>UtilityPanel</name>
    <message>
        <location filename="../../src/widgets/panel/utilitypanel.cpp" line="114"/>
        <source>Close</source>
        <translation>Zavrieť</translation>
    </message>
</context>
<context>
    <name>VisualsEditor</name>
    <message>
        <location filename="../../src/config/visualseditor.cpp" line="61"/>
        <source>Opacity of area outside selection:</source>
        <translation>Priehľadnosť oblasti mimo výberu:</translation>
    </message>
    <message>
        <location filename="../../src/config/visualseditor.cpp" line="89"/>
        <source>Button Selection</source>
        <translation>Výber tlačidiel</translation>
    </message>
    <message>
        <location filename="../../src/config/visualseditor.cpp" line="95"/>
        <source>Select All</source>
        <translation>Vybrať všetky</translation>
    </message>
</context>
</TS>
